@@ -28,7 +28,9 @@ class Depend(Decorator):
                 return Force(attempt)
         result = await interface.dispatcher_interface.broadcast.Executor(
             target=self.depend_callable,
-            dispatchers=dispatcher_mixin_handler(interface.event.Dispatcher),
+            dispatchers=interface.dispatcher_interface.execution_contexts[
+                -1
+            ].dispatchers,
         )
 
         if self.cache:
@@ -48,9 +50,7 @@ class OptionalParam(Decorator):
                 await interface.dispatcher_interface.lookup_param(
                     interface.dispatcher_interface.name,
                     interface.dispatcher_interface.annotation.__args__[0]
-                    if isinstance(
-                        interface.dispatcher_interface.annotation, typing._GenericAlias  # type: ignore
-                    )
+                    if isinstance(interface.dispatcher_interface.annotation, typing._GenericAlias)  # type: ignore
                     and type(None) in interface.dispatcher_interface.annotation.__args__
                     else interface.dispatcher_interface.annotation,
                     self.origin,
